package com.srs.teacher.service;

import java.util.List;

import com.baomidou.mybatisplus.extension.service.IService;
import com.srs.teacher.domain.SysPerformanceActive;
import com.srs.teacher.domain.SysPerformanceRw;
import org.apache.ibatis.annotations.Param;

/**
 * 综合素质-承担任务Service接口
 *
 * @author srs
 * @date 2024-06-17
 */
public interface ISysPerformanceRwService extends IService<SysPerformanceRw> {
    /**
     * 查询综合素质-承担任务
     *
     * @param id 综合素质-承担任务主键
     * @return 综合素质-承担任务
     */
    public SysPerformanceRw selectSysPerformanceRwById(Long id);

    /**
     * 查询综合素质-承担任务
     *
     * @param fdName 综合素质-承担任务主键
     * @return 综合素质-承担任务
     */
    public SysPerformanceRw selectSysPerformanceRwByFdyName(@Param("fdName") String fdName, @Param("years") String years);

    /**
     * 查询综合素质-承担任务列表
     *
     * @param sysPerformanceRw 综合素质-承担任务
     * @return 综合素质-承担任务集合
     */
    List<SysPerformanceRw> selectSysPerformanceRwList(SysPerformanceRw sysPerformanceRw);

    /**
     * 新增综合素质-承担任务
     *
     * @param sysPerformanceRw 综合素质-承担任务
     * @return 结果
     */
    int insertSysPerformanceRw(SysPerformanceRw sysPerformanceRw);

    /**
     * 修改综合素质-承担任务
     *
     * @param sysPerformanceRw 综合素质-承担任务
     * @return 结果
     */
    int updateSysPerformanceRw(SysPerformanceRw sysPerformanceRw);

    /**
     * 批量删除综合素质-承担任务
     *
     * @param ids 需要删除的综合素质-承担任务主键集合
     * @return 结果
     */
    int deleteSysPerformanceRwByIds(Long[] ids);

    /**
     * 删除综合素质-承担任务信息
     *
     * @param id 综合素质-承担任务主键
     * @return 结果
     */
    int deleteSysPerformanceRwById(Long id);
}
